ChangesResult

Struct ChangesResult 

#[non_exhaustive]
pub struct ChangesResult { pub created: Vec<Id>, pub updated: Vec<Id>, pub destroyed: Vec<Id>, pub has_more_changes: bool, pub new_state: State, }
Result of a /changes call (RFC 8620 5.2).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
created: Vec<Id>

Ids of objects that were created since sinceState.

updated: Vec<Id>

Ids of objects that were updated since sinceState.

destroyed: Vec<Id>

Ids of objects that were destroyed since sinceState.

has_more_changes: bool

true if there are more changes beyond this batch.

new_state: State

The current state token after applying all reported changes.

Implementations

Source

impl ChangesResult

pub fn new( created: Vec<Id>, updated: Vec<Id>, destroyed: Vec<Id>, has_more_changes: bool, new_state: State, ) -> Self

Construct a ChangesResult.