QueryChangesResult

Struct QueryChangesResult 

#[non_exhaustive]
pub struct QueryChangesResult { pub old_query_state: State, pub new_query_state: State, pub total: Option<u64>, pub removed: Vec<Id>, pub added: Vec<AddedItem>, }
Result of a /queryChanges call (RFC 8620 5.6).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
old_query_state: State

The query state token supplied by the client in sinceQueryState.

new_query_state: State

The current query state token.

total: Option<u64>

Total number of results in the new query, if the backend can calculate it.

removed: Vec<Id>

Ids removed from the result set since oldQueryState.

added: Vec<AddedItem>

Ids added to the result set since oldQueryState, with their positions.

Implementations

Source

impl QueryChangesResult

pub fn new( old_query_state: State, new_query_state: State, total: Option<u64>, removed: Vec<Id>, added: Vec<AddedItem>, ) -> Self

Construct a QueryChangesResult.