#[non_exhaustive]pub enum SetErrorType {
Show 23 variants
Forbidden,
OverQuota,
TooLarge,
RateLimit,
NotFound,
InvalidPatch,
WillDestroy,
InvalidProperties,
Singleton,
AlreadyExists,
MailboxHasChild,
MailboxHasEmail,
TooManyKeywords,
TooManyMailboxes,
BlobNotFound,
ForbiddenFrom,
InvalidEmail,
TooManyRecipients,
NoRecipients,
InvalidRecipients,
ForbiddenMailFrom,
ForbiddenToSend,
CannotUnsend,
}Expand description
The machine-readable type for a SetError (RFC 8620 5.3 and RFC 8621).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Forbidden
The action would violate an ACL or other access control policy.
OverQuota
Creating or modifying the object would exceed a server quota.
TooLarge
The object is too large to be stored by the server.
RateLimit
The server is rate-limiting this client.
NotFound
The object to be updated or destroyed does not exist.
InvalidPatch
The patch object is not a valid JSON Merge Patch or cannot be applied.
WillDestroy
The client requested destruction of an object that will be destroyed implicitly when another object is destroyed.
InvalidProperties
One or more properties have invalid values.
Singleton
The object type is a singleton and cannot be created or destroyed.
AlreadyExists
An object with the same unique key already exists.
MailboxHasChild
RFC 8621 2.5 — Mailbox has child mailboxes and cannot be destroyed.
MailboxHasEmail
RFC 8621 2.5 — Mailbox contains emails and onDestroyRemoveEmails is false.
TooManyKeywords
RFC 8621 5.5 — Too many keywords on the Email.
TooManyMailboxes
RFC 8621 5.5 — Email is in too many mailboxes.
BlobNotFound
RFC 8621 5.5 — A referenced blob was not found.
ForbiddenFrom
RFC 8621 6.3 — The from address is not permitted for this Identity.
InvalidEmail
RFC 8621 7.5 — The Email is invalid for submission.
TooManyRecipients
RFC 8621 7.5 — Too many recipients.
NoRecipients
RFC 8621 7.5 — No recipients specified.
InvalidRecipients
RFC 8621 7.5 — One or more recipient addresses are invalid.
ForbiddenMailFrom
RFC 8621 7.5 — The MAIL FROM address is not permitted.
ForbiddenToSend
RFC 8621 7.5 — The user does not have send permission.
CannotUnsend
RFC 8621 7.5 — The submission cannot be undone.