#[non_exhaustive]pub struct QueryResult {
pub ids: Vec<Id>,
pub position: i64,
pub total: Option<u64>,
pub query_state: State,
pub can_calculate_changes: bool,
}Expand description
Result of a /query call (RFC 8620 5.5).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ids: Vec<Id>The ordered list of matching object ids.
position: i64The 0-based index of the first returned id in the complete result list.
total: Option<u64>Total number of results, if the backend can calculate it.
query_state: StateOpaque query state token for subsequent /queryChanges calls.
can_calculate_changes: boolWhether the backend supports /queryChanges for this query.
Implementations